==> ejc-rmat-api-3.0.0-20210625.063007-40-sources.jar: com/ejianc/business/rmat/vo/RentChangeRecordVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 设备合同变更记录
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
public class RentChangeRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 合同金额
     */
    private BigDecimal contractTaxMny;

    /**
     * 初始版本金额
     */
    private BigDecimal baseTaxMoney;

    /**
     * 累计变更金额
     */
    private BigDecimal sumChangeMny;

    /**
     * 累计变更率
     */
    private BigDecimal sumScale;

    /**
     * 变更状态1-未变更 2-变更中 3-已变更
     */
    private Integer changeStatus;

    /**
     * 结算类型(0:过程结算，1:最终结算)
     */
    private Integer settlementType;

    // 设备明细子表
    private List<RentChangeVO> changeRecord = new ArrayList<RentChangeVO>();

    public Integer getSettlementType() {
        return settlementType;
    }

    public void setSettlementType(Integer settlementType) {
        this.settlementType = settlementType;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getBaseTaxMoney() {
        return baseTaxMoney;
    }

    public void setBaseTaxMoney(BigDecimal baseTaxMoney) {
        this.baseTaxMoney = baseTaxMoney;
    }

    public BigDecimal getSumChangeMny() {
        return sumChangeMny;
    }

    public void setSumChangeMny(BigDecimal sumChangeMny) {
        this.sumChangeMny = sumChangeMny;
    }

    public BigDecimal getSumScale() {
        return sumScale;
    }

    public void setSumScale(BigDecimal sumScale) {
        this.sumScale = sumScale;
    }

    public List<RentChangeVO> getChangeRecord() {
        return changeRecord;
    }

    public void setChangeRecord(List<RentChangeVO> changeRecord) {
        this.changeRecord = changeRecord;
    }

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
}

==> ejc-rmat-api-3.0.0-20221025.092358-93-sources.jar: com/ejianc/business/rmat/vo/RentChangeRecordVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 设备合同变更记录
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
public class RentChangeRecordVO extends BaseVO {

    private static final long serialVersionUID = 1L;

    /**
     * 合同主键
     */
    private Long contractId;

    /**
     * 合同金额
     */
    private BigDecimal contractTaxMny;

    /**
     * 初始版本金额
     */
    private BigDecimal baseTaxMoney;

    /**
     * 累计变更金额
     */
    private BigDecimal sumChangeMny;

    /**
     * 累计变更率
     */
    private BigDecimal sumScale;

    /**
     * 变更状态1-未变更 2-变更中 3-已变更
     */
    private Integer changeStatus;

    /**
     * 结算类型(0:过程结算，1:最终结算)
     */
    private Integer settlementType;

    // 设备明细子表
    private List<RentChangeVO> changeRecord = new ArrayList<RentChangeVO>();

    /**
     * 组织主键
     */
    private Long orgId;

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Integer getSettlementType() {
        return settlementType;
    }

    public void setSettlementType(Integer settlementType) {
        this.settlementType = settlementType;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public BigDecimal getBaseTaxMoney() {
        return baseTaxMoney;
    }

    public void setBaseTaxMoney(BigDecimal baseTaxMoney) {
        this.baseTaxMoney = baseTaxMoney;
    }

    public BigDecimal getSumChangeMny() {
        return sumChangeMny;
    }

    public void setSumChangeMny(BigDecimal sumChangeMny) {
        this.sumChangeMny = sumChangeMny;
    }

    public BigDecimal getSumScale() {
        return sumScale;
    }

    public void setSumScale(BigDecimal sumScale) {
        this.sumScale = sumScale;
    }

    public List<RentChangeVO> getChangeRecord() {
        return changeRecord;
    }

    public void setChangeRecord(List<RentChangeVO> changeRecord) {
        this.changeRecord = changeRecord;
    }

    public Integer getChangeStatus() {
        return changeStatus;
    }

    public void setChangeStatus(Integer changeStatus) {
        this.changeStatus = changeStatus;
    }
}
